@@ -23,7 +23,7 @@
  */
 
 #include <gtk/gtk.h>
-#include "libgmlib/gmlib.h"
+#include <gmlib.h>
 
 #ifdef GIO_ENABLED
 #include <gio/gio.h>
@@ -32,10 +32,13 @@
 #ifndef _COMMON_H
 #define _COMMON_H
 
+#define VO					"vo"
 #define AUDIO_DEVICE_NAME   "audio-device-name"
 #define ALSA_MIXER			"alsa-mixer"
 #define VOLUME				"volume"
 #define AUDIO_CHANNELS		"audio-channels"
+#define USE_HARDWARE_CODECS "use-hardware-codecs"
+#define USE_CRYSTALHD_CODECS "use-crystalhd-codecs"
 #define USE_HW_AUDIO		"use-hw-audio"
 #define SOFTVOL				"softvol"
 #define VOLUME_GAIN			"volume-gain"
@@ -55,6 +58,9 @@
 #define SHOWDETAILS				"show-details"
 #define SHOW_CONTROLS			"show-controls"
 
+#define AUDIO_LANG				"audio-lang"
+#define SUBTITLE_LANG			"subtitle-lang"
+
 #define DISABLEASS      		"disable-ass"
 #define DISABLEEMBEDDEDFONTS    "disable-embeddedfonts"
 #define DISABLEDEINTERLACE		"disable-deinterlace"
@@ -109,6 +115,8 @@
 #define DISABLE_EMBEDDING	"disable-embedding"
 #define DISABLE_EMBEDDED_SCALING "disable-embedded-scaling"
 
+#define ACCELERATOR_KEYS	"accelerator-keys"
+
 // set this to true in gconf/dconf when using with gnome global menus
 #define ENABLE_GLOBAL_MENU  "enable-global-menu"
 
@@ -207,6 +215,41 @@ enum {
     N_COLUMNS
 };
 
+typedef enum {
+    FILE_OPEN_LOCATION,
+    EDIT_SCREENSHOT,
+    EDIT_PREFERENCES,
+    VIEW_PLAYLIST,
+    VIEW_INFO,
+    VIEW_DETAILS,
+    VIEW_METER,
+    VIEW_FULLSCREEN,
+    VIEW_ASPECT,
+    VIEW_SUBTITLES,
+    VIEW_DECREASE_SIZE,
+    VIEW_INCREASE_SIZE,
+    VIEW_ANGLE,
+    VIEW_CONTROLS,
+    KEY_COUNT
+} AcceleratorKeys;
+
+#define ACCEL_PATH_OPEN_LOCATION "<GNOME MPlayer>/File/Open Location"
+#define ACCEL_PATH_EDIT_SCREENSHOT "<GNOME MPlayer>/Edit/Screenshot"
+#define ACCEL_PATH_EDIT_PREFERENCES "<GNOME MPlayer>/Edit/Preferences"
+#define ACCEL_PATH_VIEW_PLAYLIST "<GNOME MPlayer>/View/Playlist"
+#define ACCEL_PATH_VIEW_INFO "<GNOME MPlayer>/View/Info"
+#define ACCEL_PATH_VIEW_DETAILS "<GNOME MPlayer>/View/Details"
+#define ACCEL_PATH_VIEW_METER "<GNOME MPlayer>/View/Meter"
+#define ACCEL_PATH_VIEW_FULLSCREEN "<GNOME MPlayer>/View/Fullscreen"
+#define ACCEL_PATH_VIEW_ASPECT "<GNOME MPlayer>/View/Aspect"
+#define ACCEL_PATH_VIEW_SUBTITLES "<GNOME MPlayer>/View/Subtitles"
+#define ACCEL_PATH_VIEW_DECREASE_SIZE "<GNOME MPlayer>/View/Decrease Size"
+#define ACCEL_PATH_VIEW_INCREASE_SIZE "<GNOME MPlayer>/View/Increase Size"
+#define ACCEL_PATH_VIEW_ANGLE "<GNOME MPlayer>/View/Angle"
+#define ACCEL_PATH_VIEW_CONTROLS "<GNOME MPlayer>/View/Controls"
+#define ACCEL_PATH_VIEW_NORMAL "<GNOME MPlayer>/View/Normal"
+#define ACCEL_PATH_VIEW_DOUBLE "<GNOME MPlayer>/View/Double"
+
 typedef struct _MetaData {
     gchar *uri;
     gchar *title;
@@ -243,6 +286,9 @@ typedef struct _ButtonDef {
 #define METER_BARS 		40
 gint buckets[METER_BARS];
 gint max_buckets[METER_BARS];
+gchar **accel_keys;
+gchar **accel_keys_description;
+GtkWidget *config_accel_keys[KEY_COUNT];
 
 //Define MIME for DnD
 #define DRAG_NAME_0		"text/plain"
@@ -284,6 +330,9 @@ gint stored_window_width, stored_window_height;
 gboolean adjusting;
 gchar vm[10];
 gchar *vo;
+gchar *option_vo;
+gboolean use_hardware_codecs;
+gboolean use_crystalhd_codecs;
 AudioDevice audio_device;
 gchar *audio_device_name;
 gint audio_channels;
@@ -340,6 +389,7 @@ gint subtitle_fuzziness;
 gboolean quit_on_complete;
 gchar *mplayer_bin;
 gchar *mplayer_dvd_device;
+gchar *option_dvd_device;
 gchar *extraopts;
 gboolean resize_on_new_media;
 gboolean single_instance;
@@ -480,9 +530,6 @@ gboolean update_audio_meter(gpointer data);
 
 void set_media_player_attributes(GtkWidget * widget);
 
-gboolean update_mplayer_config();
-gboolean read_mplayer_config();
-
 void retrieve_metadata(gpointer data, gpointer user_data);
 
 gchar *default_playlist;
