@@ -31,8 +31,8 @@
 #ifdef X11_ENABLED
 #include <gdk/gdkx.h>
 #endif
-#include "libgmlib/gmlib.h"
-#include "libgmtk/gmtk.h"
+#include <gmlib.h>
+#include <gmtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -109,6 +109,7 @@ GtkMenuItem *menuitem_view_sep1;
 GtkMenuItem *menuitem_view_onetoone;
 GtkMenuItem *menuitem_view_twotoone;
 GtkMenuItem *menuitem_view_onetotwo;
+GtkMenuItem *menuitem_view_onetoonepointfive;
 GtkMenuItem *menuitem_view_sep4;
 GtkMenuItem *menuitem_view_aspect;
 GtkMenu *menu_view_aspect;
@@ -228,6 +229,8 @@ GtkTooltips *volume_tip;
 GtkWidget *config_window;
 
 GtkWidget *config_vo;
+GtkWidget *config_hardware_codecs;
+GtkWidget *config_crystalhd_codecs;
 GtkWidget *config_ao;
 GtkWidget *config_mixer;
 GtkWidget *config_audio_channels;
@@ -350,10 +353,11 @@ void update_status_icon();
 void setup_accelerators();
 gboolean set_software_volume(gdouble * data);
 gboolean set_adjust_layout(gpointer data);
+gboolean get_key_and_modifier(gchar * keyval, guint * key, GdkModifierType * modifier);
+gboolean accel_key_key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer data);
+void assign_default_keys();
+void reset_keys_callback(GtkButton * button, gpointer data);
+gint get_index_from_key_and_modifier(guint key, GdkModifierType modifier);
 
 void show_fs_controls();
 void hide_fs_controls();
-
-// GSEAL accessors
-void get_allocation(GtkWidget * widget, GtkAllocation * allocation);
-GdkWindow *get_window(GtkWidget * widget);
