@@ -43,6 +43,7 @@
 #include "common.h"
 #include "support.h"
 #include "dbus-interface.h"
+#include "gmtk.h"
 
 
 static GOptionEntry entries[] = {
@@ -142,6 +143,8 @@ static GOptionEntry entries[] = {
     {"disable_cover_art_fetch", 0, 0, G_OPTION_ARG_NONE, &disable_cover_art_fetch,
      N_("Don't fetch new cover art images"),
      NULL},
+    {"dvd_device", 0, 0, G_OPTION_ARG_STRING, &option_dvd_device, N_("DVD Device Name"), "Path to device or folder"},
+    {"vo", 0, 0, G_OPTION_ARG_STRING, &option_vo, N_("Video Output Device Name"), "mplayer vo name"},
     {NULL}
 };
 
@@ -299,7 +302,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         printf("is playlist %i\n", playlist);
     }
 
-    get_allocation(GTK_WIDGET(media), &alloc);
+    gmtk_get_allocation(GTK_WIDGET(media), &alloc);
     if (width == 0 || height == 0) {
         alloc.width = 16;
         alloc.height = 16;
@@ -534,6 +537,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     idledata->width = width;
     idledata->height = height;
 
+    idledata->retry_on_full_cache = FALSE;
     idledata->cachepercent = -1.0;
     g_strlcpy(idledata->info, uri, 1024);
     set_media_info(idledata);
@@ -561,6 +565,8 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
             gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVD);
         } else if (g_str_has_prefix(uri, "cdda")) {
             gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_CD);
+        } else if (g_str_has_prefix(uri, "cddb")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_CD);
         } else if (g_str_has_prefix(uri, "vcd")) {
             gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_VCD);
         } else if (g_str_has_prefix(uri, "tv")) {
@@ -593,6 +599,52 @@ static void hup_handler(int signum)
 }
 #endif
 
+void assign_default_keys()
+{
+    if (!accel_keys[FILE_OPEN_LOCATION]) {
+        accel_keys[FILE_OPEN_LOCATION] = g_strdup("4+l");
+    }
+    if (!accel_keys[EDIT_SCREENSHOT]) {
+        accel_keys[EDIT_SCREENSHOT] = g_strdup("4+t");
+    }
+    if (!accel_keys[EDIT_PREFERENCES]) {
+        accel_keys[EDIT_PREFERENCES] = g_strdup("4+p");
+    }
+    if (!accel_keys[VIEW_PLAYLIST]) {
+        accel_keys[VIEW_PLAYLIST] = g_strdup("F9");
+    }
+    if (!accel_keys[VIEW_INFO]) {
+        accel_keys[VIEW_INFO] = g_strdup("i");
+    }
+    if (!accel_keys[VIEW_DETAILS]) {
+        accel_keys[VIEW_DETAILS] = g_strdup("4+d");
+    }
+    if (!accel_keys[VIEW_METER]) {
+        accel_keys[VIEW_METER] = g_strdup("4+m");
+    }
+    if (!accel_keys[VIEW_FULLSCREEN]) {
+        accel_keys[VIEW_FULLSCREEN] = g_strdup("4+f");
+    }
+    if (!accel_keys[VIEW_ASPECT]) {
+        accel_keys[VIEW_ASPECT] = g_strdup("a");
+    }
+    if (!accel_keys[VIEW_SUBTITLES]) {
+        accel_keys[VIEW_SUBTITLES] = g_strdup("v");
+    }
+    if (!accel_keys[VIEW_DECREASE_SIZE]) {
+        accel_keys[VIEW_DECREASE_SIZE] = g_strdup("1+R");
+    }
+    if (!accel_keys[VIEW_INCREASE_SIZE]) {
+        accel_keys[VIEW_INCREASE_SIZE] = g_strdup("1+T");
+    }
+    if (!accel_keys[VIEW_ANGLE]) {
+        accel_keys[VIEW_ANGLE] = g_strdup("4+a");
+    }
+    if (!accel_keys[VIEW_CONTROLS]) {
+        accel_keys[VIEW_CONTROLS] = g_strdup("c");
+    }
+}
+
 int main(int argc, char *argv[])
 {
     struct stat buf;
@@ -604,6 +656,9 @@ int main(int argc, char *argv[])
     GOptionContext *context;
     gint i;
     gdouble volume = 100.0;
+    gchar *accelerator_keys;
+    gchar **parse;
+    GtkSettings *gtk_settings;
 
 #ifndef OS_WIN32
     struct sigaction sa;
@@ -773,7 +828,10 @@ int main(int argc, char *argv[])
 
     gm_store = gm_pref_store_new("gnome-mplayer");
     gmp_store = gm_pref_store_new("gecko-mediaplayer");
+    vo = gm_pref_store_get_string(gm_store, VO);
     audio_device.alsa_mixer = gm_pref_store_get_string(gm_store, ALSA_MIXER);
+    use_hardware_codecs = gm_pref_store_get_boolean(gm_store, USE_HARDWARE_CODECS);
+    use_crystalhd_codecs = gm_pref_store_get_boolean(gm_store, USE_CRYSTALHD_CODECS);
     osdlevel = gm_pref_store_get_int(gm_store, OSDLEVEL);
     pplevel = gm_pref_store_get_int(gm_store, PPLEVEL);
 #ifndef HAVE_ASOUNDLIB
@@ -807,6 +865,10 @@ int main(int argc, char *argv[])
     use_mediakeys = gm_pref_store_get_boolean_with_default(gm_store, USE_MEDIAKEYS, use_mediakeys);
     use_defaultpl = gm_pref_store_get_boolean_with_default(gm_store, USE_DEFAULTPL, use_defaultpl);
     metadata_codepage = gm_pref_store_get_string(gm_store, METADATACODEPAGE);
+
+    alang = gm_pref_store_get_string(gm_store, AUDIO_LANG);
+    slang = gm_pref_store_get_string(gm_store, SUBTITLE_LANG);
+
     subtitlefont = gm_pref_store_get_string(gm_store, SUBTITLEFONT);
     subtitle_scale = gm_pref_store_get_float(gm_store, SUBTITLESCALE);
     if (subtitle_scale < 0.25) {
@@ -848,6 +910,33 @@ int main(int argc, char *argv[])
     extraopts = gm_pref_store_get_string(gm_store, EXTRAOPTS);
     use_xscrnsaver = gm_pref_store_get_boolean_with_default(gm_store, USE_XSCRNSAVER, use_xscrnsaver);
 
+    accelerator_keys = gm_pref_store_get_string(gm_store, ACCELERATOR_KEYS);
+    accel_keys = g_strv_new(KEY_COUNT);
+    accel_keys_description = g_strv_new(KEY_COUNT);
+    if (accelerator_keys != NULL) {
+        parse = g_strsplit(accelerator_keys, " ", KEY_COUNT);
+        for (i = 0; i < g_strv_length(parse); i++) {
+            accel_keys[i] = g_strdup(parse[i]);
+        }
+        g_free(accelerator_keys);
+        g_strfreev(parse);
+    }
+    assign_default_keys();
+    accel_keys_description[FILE_OPEN_LOCATION] = g_strdup(_("Open Location"));
+    accel_keys_description[EDIT_SCREENSHOT] = g_strdup(_("Take Screenshot"));
+    accel_keys_description[EDIT_PREFERENCES] = g_strdup(_("Preferences"));
+    accel_keys_description[VIEW_PLAYLIST] = g_strdup(_("Playlist"));
+    accel_keys_description[VIEW_INFO] = g_strdup(_("Media Info"));
+    accel_keys_description[VIEW_DETAILS] = g_strdup(_("Details"));
+    accel_keys_description[VIEW_METER] = g_strdup(_("Audio Meter"));
+    accel_keys_description[VIEW_FULLSCREEN] = g_strdup(_("Full Screen"));
+    accel_keys_description[VIEW_ASPECT] = g_strdup(_("Aspect"));
+    accel_keys_description[VIEW_SUBTITLES] = g_strdup(_("Subtitles"));
+    accel_keys_description[VIEW_DECREASE_SIZE] = g_strdup(_("Decrease Subtitle Size"));
+    accel_keys_description[VIEW_INCREASE_SIZE] = g_strdup(_("Increase Subtitle Size"));
+    accel_keys_description[VIEW_ANGLE] = g_strdup(_("Switch Angle"));
+    accel_keys_description[VIEW_CONTROLS] = g_strdup(_("Controls"));
+
     remember_loc = gm_pref_store_get_boolean(gm_store, REMEMBER_LOC);
     loc_window_x = gm_pref_store_get_int(gm_store, WINDOW_X);
     loc_window_y = gm_pref_store_get_int(gm_store, WINDOW_Y);
@@ -862,9 +951,6 @@ int main(int argc, char *argv[])
     audio_device_name = gm_pref_store_get_string(gm_store, AUDIO_DEVICE_NAME);
     audio_device.description = g_strdup(audio_device_name);
 
-
-    read_mplayer_config();
-
     context = g_option_context_new(_("[FILES...] - GNOME Media player based on MPlayer"));
 #ifdef GTK2_12_ENABLED
     g_option_context_set_translation_domain(context, "UTF-8");
@@ -884,8 +970,10 @@ int main(int argc, char *argv[])
     if (reallyverbose)
         verbose = 2;
 
-    if (verbose)
+    if (verbose) {
         printf(_("GNOME MPlayer v%s\n"), VERSION);
+        printf(_("gmtk v%s\n"), gmtk_version());
+    }
 
     if (cache_size == 0)
         cache_size = gm_pref_store_get_int(gm_store, CACHE_SIZE);
@@ -906,8 +994,6 @@ int main(int argc, char *argv[])
     gm_pref_store_free(gm_store);
     gm_pref_store_free(gmp_store);
 
-    read_mplayer_config();
-
     if (verbose && embed_window) {
         printf("embedded in window id 0x%x\n", embed_window);
     }
@@ -941,7 +1027,6 @@ int main(int argc, char *argv[])
         }
     }
 
-
     if (large_buttons)
         button_size = GTK_ICON_SIZE_DIALOG;
 
@@ -967,6 +1052,12 @@ int main(int argc, char *argv[])
                            G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
                            G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_BOOLEAN);
 
+    // only use dark theme if not embedded, otherwise use the default theme                                       
+    if (embed_window <= 0) {
+        gtk_settings = gtk_settings_get_default();
+        g_object_set(G_OBJECT(gtk_settings), "gtk-application-prefer-dark-theme", TRUE, NULL);
+    }
+
     create_window(embed_window);
 
     autopause = FALSE;
