@@ -86,4 +86,7 @@ const char *mime_types[] = {
     "video/webm",
     "video/x-webm",
     "application/x-extension-webm",
+    "video/mp2t",
+    "video/vnd.mpegurl",
+    "video/x-mpegurl",
 };
