@@ -901,161 +901,6 @@ gint parse_vcd(gchar * filename)
     return ret;
 }
 
-gboolean update_mplayer_config()
-{
-
-    GKeyFile *config = g_key_file_new();
-    gchar *data;
-    gchar *def;
-    GError *error;
-    gchar *filename;
-
-    error = NULL;
-
-    if (g_getenv("HOME") == NULL)
-        return FALSE;
-
-    filename = g_strdup_printf("%s/.mplayer/config", g_getenv("HOME"));
-    g_key_file_load_from_file(config, filename, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error);
-
-    if (error != NULL) {
-        //printf("%i\n%s", error->code, error->message);
-        if (error->code == 4) {
-            g_file_get_contents(filename, &data, NULL, NULL);
-            //printf("%s\n", data);
-            def = g_strconcat("[default]\n", data, NULL);
-            g_file_set_contents(filename, def, -1, NULL);
-            g_free(data);
-            g_free(def);
-            g_error_free(error);
-            error = NULL;
-            g_key_file_load_from_file(config, filename, G_KEY_FILE_KEEP_TRANSLATIONS, &error);
-            if (error != NULL) {
-                // something bad happened...
-                g_error_free(error);
-                error = NULL;
-            }
-        } else {
-            g_error_free(error);
-            error = NULL;
-        }
-    }
-
-    if (vo != NULL && strlen(vo) != 0) {
-        g_key_file_set_string(config, "gnome-mplayer", "vo", vo);
-        if (g_ascii_strcasecmp(vo, "x11") == 0) {
-            // make full screen work when using x11
-            g_key_file_set_string(config, "gnome-mplayer", "zoom", "1");
-            // make advanced video controls work on x11
-            g_key_file_set_string(config, "gnome-mplayer", "vf", "eq2");
-        }
-
-        if (g_ascii_strcasecmp(vo, "xv") == 0) {
-            // make advanced video controls work on xv
-            g_key_file_remove_key(config, "gnome-mplayer", "zoom", NULL);
-            g_key_file_set_string(config, "gnome-mplayer", "vf", "eq2");
-        }
-
-        if (g_ascii_strcasecmp(vo, "xvmc") == 0 && !disable_deinterlace) {
-            g_key_file_set_string(config, "gnome-mplayer", "vo", "xvmc:bobdeint:queue");
-        }
-
-        if (g_ascii_strcasecmp(vo, "gl") == 0 || g_ascii_strcasecmp(vo, "gl2") == 0
-            || g_ascii_strcasecmp(vo, "xvmc") == 0 || g_ascii_strcasecmp(vo, "vdpau") == 0) {
-            // if vf=eq2 is set and we use gl, then mplayer crashes
-            g_key_file_remove_key(config, "gnome-mplayer", "zoom", NULL);
-            g_key_file_remove_key(config, "gnome-mplayer", "vf", NULL);
-        }
-
-
-    } else {
-        g_key_file_remove_key(config, "gnome-mplayer", "vo", NULL);
-    }
-
-    if (alang != NULL && strlen(alang) != 0) {
-        g_key_file_set_string(config, "gnome-mplayer", "alang", alang);
-    } else {
-        g_key_file_remove_key(config, "gnome-mplayer", "alang", NULL);
-    }
-
-    if (slang != NULL && strlen(slang) != 0) {
-        g_key_file_set_string(config, "gnome-mplayer", "slang", slang);
-    } else {
-        g_key_file_remove_key(config, "gnome-mplayer", "slang", NULL);
-    }
-
-    g_key_file_remove_key(config, "gnome-mplayer", "really-quiet", NULL);
-    g_key_file_set_string(config, "gnome-mplayer", "msglevel", "all=5");
-
-    data = g_key_file_to_data(config, NULL, NULL);
-    //printf("%i\n%s", strlen(data), data);
-
-    g_file_set_contents(filename, data, -1, NULL);
-    g_free(data);
-    g_free(filename);
-    g_key_file_free(config);
-
-    return TRUE;
-}
-
-gboolean read_mplayer_config()
-{
-
-    GKeyFile *config = g_key_file_new();
-    gchar *data;
-    gchar *def;
-    GError *error;
-    gchar *filename;
-
-    error = NULL;
-
-    if (g_getenv("HOME") == NULL)
-        return FALSE;
-
-    // printf("home is set to %s",g_getenv("HOME"));
-
-    filename = g_strdup_printf("%s/.mplayer/config", g_getenv("HOME"));
-    g_key_file_load_from_file(config, filename, G_KEY_FILE_KEEP_TRANSLATIONS, &error);
-
-    if (error != NULL) {
-        //printf("%i\n%s\n", error->code, error->message);
-        if (error->code == 4) {
-            g_file_get_contents(filename, &data, NULL, NULL);
-            //printf("%s\n", data);
-            def = g_strconcat("[default]\n", data, NULL);
-            g_file_set_contents(filename, def, -1, NULL);
-            g_free(data);
-
-            g_error_free(error);
-            error = NULL;
-            g_key_file_load_from_data(config,
-                                      (const gchar *) def, strlen(def),
-                                      G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error);
-            g_free(def);
-
-        }
-    }
-
-    if (vo != NULL)
-        g_free(vo);
-    vo = g_key_file_get_string(config, "gnome-mplayer", "vo", NULL);
-    alang = g_key_file_get_string(config, "gnome-mplayer", "alang", NULL);
-    slang = g_key_file_get_string(config, "gnome-mplayer", "slang", NULL);
-
-    if (vo != NULL && g_ascii_strcasecmp(vo, "xvmc:bobdeint:queue") == 0) {
-        g_free(vo);
-        vo = g_strdup("xvmc");
-    }
-
-    g_free(filename);
-    g_key_file_free(config);
-
-    if (verbose)
-        printf("read mplayer config values: vo = %s\n", vo);
-
-    return TRUE;
-}
-
 gboolean streaming_media(gchar * uri)
 {
     gboolean ret;
